@@ -1,7 +1,7 @@
 /* gok-button.c
 *
-* Copyright 2002 Sun Microsystems, Inc.,
-* Copyright 2001 University Of Toronto
+* Copyright 2002-2009 Sun Microsystems, Inc.,
+* Copyright 2001-2009 University Of Toronto
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
@@ -19,56 +19,20 @@
 * Boston, MA 02111-1307, USA.
 */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
 #include "gok-button.h"
+
 #include "gok-keyboard.h"
 #include "gok-log.h"
 #include "gok-data.h"
 #include "gok-scanner.h"
 #include "main.h"
-#include <stdio.h>
-#include <gnome.h>
 
-static void gok_button_class_init    (GokButtonClass *klass);
-static void gok_button_init          (GokButton      *gok_button);
-static gboolean gok_button_expose    (GtkWidget      *widget, GdkEventExpose *expose);
-GokKey* gok_button_find_key (GtkWidget* pWidget);
-
-static GtkToggleButtonClass *parent_class = NULL;
+static gboolean gok_button_expose   (GtkWidget *widget, GdkEventExpose *expose);
+static GokKey * gok_button_find_key (GtkWidget *pWidget);
 
 /* TODO: make image/text relationship (i.e. image on left, label on right) configurable */
 
-/**
-* gok_button_get_type
-*
-* returns: the gok button type
-**/
-GtkType
-gok_button_get_type ()
-{
-  static GtkType GokButtonType = 0;
- if (!GokButtonType)
-    {
-      static const GtkTypeInfo GokButtonInfo =
-      {
-	"GokButton",
-	sizeof (GokButton),
-	sizeof (GokButtonClass),
-	(GtkClassInitFunc) gok_button_class_init,
-	(GtkObjectInitFunc) gok_button_init,
-	NULL,
-     NULL,
-	(GtkClassInitFunc) NULL,
-      };
-
-      GokButtonType = gtk_type_unique (GTK_TYPE_TOGGLE_BUTTON, &GokButtonInfo);
-    }
-
-  return GokButtonType;
-}
+G_DEFINE_TYPE (GokButton, gok_button, GTK_TYPE_TOGGLE_BUTTON)
 
 /**
 * gok_button_class_init
@@ -78,9 +42,8 @@ gok_button_get_type ()
 static void
 gok_button_class_init (GokButtonClass *klass)
 {
-	GtkWidgetClass   *widget_class;
-	widget_class   = (GtkWidgetClass*)   klass;
-	parent_class = g_type_class_peek_parent (klass);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+
 	widget_class->expose_event = gok_button_expose;
 }
 
@@ -289,7 +252,8 @@ void gok_button_state_changed (GtkWidget *widget, GtkStateType state, gpointer u
 *
 * Returns: A pointer to the key that holds the widget, NULL if not found.
 **/
-GokKey* gok_button_find_key (GtkWidget* pWidget)
+static GokKey *
+gok_button_find_key (GtkWidget* pWidget)
 {
 	GokKeyboard* pKeyboard;
 	GokKey* pKey;
@@ -315,7 +279,7 @@ gok_button_expose (GtkWidget      *widget,
 		   GdkEventExpose *event)
 {
  	gboolean retval = 
-		(* GTK_WIDGET_CLASS (parent_class)->expose_event) (widget, event);
+		(* GTK_WIDGET_CLASS (gok_button_parent_class)->expose_event) (widget, event);
 	
 	if (GTK_WIDGET_DRAWABLE (widget) && GOK_BUTTON (widget)->pImage) {
 		if (GOK_BUTTON (widget)->indicator_type != NULL) {
