@@ -27,7 +27,6 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <string.h>
-#include <gnome.h>
 #include <glade/glade.h>
 #include "gok-settings-dialog.h"
 #include "gok-page-keysizespace.h"
@@ -255,21 +254,10 @@ void on_button_try (GtkButton* button, gpointer user_data)
 	/* if any settings have changed then refresh the keyboard */
 	if (bDataChanged == TRUE)
 	{
-		gchar *message = g_strconcat (_("You appear to be configuring GOK to use \'core pointer\' mode."),
-					      "\n\n", 
-					      _("The device you are using to operate GOK "
-						"is also controlling the system pointer (or \'mouse pointer\'). "
-						"Conflicts with applications\' use of the pointer may interfere "
-						"with your ability to use applications or GOK.\n\n"
-						"We strongly recommend configuring your input device as an "
-						"'Extended\' input device instead; see GOK Help for more information."),
-
-					      NULL);
 		gok_main_display_scan_reset();
 
 		/* and post a warning if the new settings use corepointer */		
-		gok_main_warn (message, FALSE, FALSE);
-		g_free (message);
+		gok_main_warn_corepointer (FALSE, TRUE, FALSE);
 	}
 }
 
@@ -366,32 +354,30 @@ void on_button_help (GtkButton* pButton, gpointer user_data)
 			break;
 			
 		case 1:
-			help_link_id = "gok-keyboards";
+			help_link_id = "gok-prefs-keyboards";
 			break;
 			
 		case 2:
-			help_link_id = "gok-prefs-Actions";
+			help_link_id = "gok-prefs-actions";
 			break;
 			
 		case 3:
-			help_link_id = "gok-prefs-Feedback";
+			help_link_id = "gok-prefs-feedback";
 			break;
 
 		case 4:
-			help_link_id = "gok-prefs-Access-Methods";
+			help_link_id = "gok-prefs-accessmethods";
 			break;
 			
 		case 5:
-			help_link_id = "gok-prefs-Prediction";
+			help_link_id = "gok-prefs-prediction";
 			break;
 			
 		default:
 			break;
 	}
-	if (help_link_id)
-	{
-		gnome_help_display_desktop (NULL, "gok", "gok.xml", help_link_id, NULL);
-	}
+
+	gok_main_display_help ("gok", help_link_id);
 }
 
 /**
